@@ -1,63 +1,84 @@
 # to avoid 'no visible binding for global variable' NOTE
-globalVariables(c("r_environment", "session", "r_data", "r_state", ".",
-                  ".rs.restartR", "..density..", "Total", "tfoot", "thead",
-                  "tr", "th", "variable", "y", "matches"))
+globalVariables(
+  c(".", "..density..", "r_data", "tfoot", "th", "thead", "tr", "variable")
+)
 
 #' radiant.data
 #'
 #' @name radiant.data
 #' @docType package
 #' @import ggplot2 shiny dplyr
+#' @importFrom rlang parse_exprs
 #' @importFrom car Recode
 #' @importFrom rstudioapi insertText isAvailable
 #' @importFrom knitr knit2html knit
 #' @importFrom markdown markdownToHTML
 #' @importFrom rmarkdown render html_dependency_bootstrap pdf_document html_document word_document
-#' @importFrom pryr where object_size
 #' @importFrom magrittr %<>% %T>% %$% set_rownames set_colnames set_names divide_by add extract2
 #' @importFrom lubridate is.Date is.POSIXt now year month wday week hour minute second ymd mdy dmy ymd_hms hms hm as.duration parse_date_time
-#' @importFrom tibble rownames_to_column as_data_frame data_frame
-#' @importFrom tidyr gather_ gather spread spread_ separate
-#' @importFrom grid textGrob gpar
+#' @importFrom tidyr gather spread separate extract
 #' @importFrom gridExtra grid.arrange
 #' @importFrom shinyAce aceEditor updateAceEditor
-#' @importFrom readr read_delim write_csv locale problems
+#' @importFrom readr read_delim read_csv write_csv read_rds write_rds locale problems
+#' @importFrom readxl read_excel
 #' @importFrom base64enc dataURI
 #' @importFrom methods is
 #' @importFrom stats as.formula chisq.test dbinom median na.omit quantile sd setNames var weighted.mean
-#' @importFrom utils combn head install.packages read.table tail
+#' @importFrom utils combn head tail install.packages read.table write.table
 #' @importFrom import from
 NULL
 
+#' Exporting glue from glue
+#' @details See \code{\link[glue]{glue}} in the \code{glue} package for more details
+#' @importFrom glue glue
+#' @name glue
+#' @rdname glue
+#' @export
+NULL
+
+#' Exporting collapse from glue as glue_collapse
+#' @details See \code{\link[glue]{collapse}} in the \code{glue} package for more details
+#' @name glue_collapse
+#' @rdname glue_collapse
+#' @param ... arguments passed to \code{glue::collapse}
+#' @export
+glue_collapse <- function(...) glue::collapse(...)
+NULL
+
+#' Exporting glue_data from glue
+#' @details See \code{\link[glue:glue]{glue::glue_data()}} in the \code{glue} package for more details
+#' @importFrom glue glue_data
+#' @name glue_data
+#' @rdname glue_data
+#' @export
+NULL
+
+#' Exporting knit_print from knitr
+#' @details See \code{\link[knitr]{knit_print}} in the \code{knitr} package for more details
+#' @importFrom knitr knit_print
+#' @name knit_print
+#' @rdname knit_print
+#' @export
+NULL
+
 #' Exporting rownames_to_column from tibble
+#' @details See \code{\link[tibble]{rownames}} in the \code{tibble} package for more details
 #' @importFrom tibble rownames_to_column
 #' @name rownames_to_column
 #' @rdname rownames_to_column
 #' @export
 NULL
 
-#' Exporting data_frame
-#' @importFrom tibble data_frame
-#' @name data_frame
-#' @rdname data_frame
-#' @export
-NULL
-
-#' Exporting as_data_frame
-#' @importFrom tibble as_data_frame
-#' @name as_data_frame
-#' @rdname as_data_frame
-#' @export
-NULL
-
-#' Exporting tibble
+#' Exporting tibble from tibble
+#' @details See \code{\link[tibble]{tibble}} in the \code{tibble} package for more details
 #' @importFrom tibble tibble
 #' @name tibble
 #' @rdname tibble
 #' @export
 NULL
 
-#' Exporting as_tibble
+#' Exporting as_tibble from tibble
+#' @details See \code{\link[tibble]{as_tibble}} in the \code{tibble} package for more details
 #' @importFrom tibble as_tibble
 #' @name as_tibble
 #' @rdname as_tibble
@@ -65,6 +86,7 @@ NULL
 NULL
 
 #' Exporting tidy from broom
+#' @details See \code{\link[broom]{tidy}} in the \code{broom} package for more details
 #' @importFrom broom tidy
 #' @name tidy
 #' @rdname tidy
@@ -72,20 +94,25 @@ NULL
 NULL
 
 #' Exporting glance from broom
+#' @details See \code{\link[broom]{glance}} in the \code{broom} package for more details
 #' @importFrom broom glance
 #' @name glance
 #' @rdname glance
 #' @export
 NULL
 
-#' Exporting the kurtosi function from the psych package
+#' Exporting kurtosi from psych
+# @details See \code{\link[psych:mardia]{psych::kurtosi()}} in the \code{psych} package for more details
+#' @details See \code{\link{kurtosi}} in the \code{psych} package for more details
 #' @importFrom psych kurtosi
 #' @name kurtosi
 #' @rdname kurtosi.re
 #' @export
 NULL
 
-#' Exporting the skew function from the psych package
+#' Exporting skew from psych
+#' @details See \code{\link{skew}} in the \code{psych} package for more details
+# @details See \code{\link[psych:mardia]{psych::skew()}} in the \code{psych} package for more details
 #' @importFrom psych skew
 #' @name skew
 #' @rdname skew.re
@@ -93,7 +120,7 @@ NULL
 NULL
 
 #' Diamond prices
-#' @details A sample of 3,000 from the diamonds dataset bundeled with ggplot2. Description provided in attr(diamonds,"description")
+#' @details A sample of 3,000 from the diamonds dataset bundled with ggplot2. Description provided in attr(diamonds,"description")
 #' @docType data
 #' @keywords datasets
 #' @name diamonds
